;+
; NAME:
;    TERM_REVIEW_GIF
; PURPOSE:
;    Show the SFC pointing locations graphically for a specific
;      time range. Specific for terminators since rupture #4.
;      Dumps to .gif files for QUICK survey.
; CATEGORY:
; CALLING SEQUENCE:
;    term_review
;    term_review,filcon1,filcon2
;    term_review, tstart, tstop, sfc_rm = sfc_rm, /q
;    term_review,rm_sft=rm_sft,rm_sfc=rm_sfc,xy_sfc=xy_sfc,xy_sft=xy_sft,/wide
;      (this gives you the works)
; INPUTS:
;    filcon1, filcon2, Numerical format for filter configurations to 
;	plot:   21=Al.1/Open	26=Al.1/NuDen
;		31=AlMg/Open	36=AlMg/NuDen
;		41=Be/Open	46=Be/NuDen
;		51=Al12/Open	56=Al12/NuDen
;		61=Mg/Open	66=Mg/NuDen
;	defaults to filcon1=21, filcon2=31 (If choose only one, it
;	will still plot two configurations..DEM)
; OPTIONAL (KEYWORD) INPUT PARAMETERS:
;    tstart, tstop, any format (defaults to the current interval,
;      ie from rupture #3 to the present)
;    wide => displays the extended EW range needed to see the offpoints
;    rm_sfc, rm_sft, xy_sft, xy_sfc send back info 
;    compare => plot showing core distributions of SFM and SFC images
;    qstop
;    set => offpoint information for re-setting OG 32
; ROUTINES CALLED
;    FINDFILE, GT_FILTA, GT_FILTB, RD_ROADMAP, !stime
; OUTPUTS:
;    rm_sfc and rm_sft, the roadmap files for the selected SFC(SFT) entries 
; COMMON BLOCKS:
; SIDE EFFECTS:
; RESTRICTIONS:
;    Grabs IDL 0 and graphs the (x,y) coordinates of the SFC's from the
;      two soft filters
; MODIFICATION HISTORY:
;    HSH, written 24-aug-96 - one day before rupture!
;    HSH, added some stuff 30-aug-96
;    HSH, looked things over 18-sep-96
;    HSH, removed hard-wired directories and enlarged, 27-Nov-96
;    HSH, added a table of SFC successes, 29-Nov-96
;    HSH, colored the most recent point, 18-Dec-96
;    HSH, added "quiet" keyword, 1-Mar-97
;    HSH, added xy outputs and /plot, 28-Mar-97
;    HSH, made the default plot better for monitoring NS drift. /wide
;         now gives the whole offpointing EW range.
;    HSH, switched to index.his to get sxt_cen values (Sam's suggestion), 
;         16-May-97
;    HSH, fixed to work with TEK graphics, 1-jun-97
;    HSH, added /compare 18-jul-97
;    HSH, added /set 14-aug-97
;    DEM, added options of plotting different filters, 19-oct-97
;    HSH, changed /compare to look at current SFD's, 23-oct-97
;    HSH, routine pointing update 30-Oct-97
;    HSH, repaired /compare and /set functions 22-Dec-97
;    HSH, routine pointing update 24-Dec-97 (last entry like this!)
;    HSH, updated for rupture #4 4-Feb-98 (default tstart = 24-Jan-98)
;    HSH, specified .gif output files
;    DMcK, added PLOTTIME to output 6-jan-99.
;    DMcK, colored SFD points in /comp for better visibility, and
;         cleaned up textual output related to addition of 19-oct-97,
;         08-feb-99.
;-

pro term_review_gif, filcon1, filcon2, tstart=tstart, tstop=tstop, $
     rm_sfc = rm_sfc, rm_sft = rm_sft, $
     xy_sfc = xy_sfc, xy_sft = xy_sft, qstop = qstop, quiet=quiet, wide=wide,$
     xy_sfm = xy_sfm, compare = compare, set=set
set_plot,'z
compare=1
inf_sft = findfile('$DIR_SXT_SFT/sft*')
inf_sfc = findfile('$DIR_SXT_SFC/sfc*')
rd_roadmap,inf_sft,rm_sft0
rd_roadmap,inf_sfc,rm_sfc0
if n_elements(filcon1) eq 0 then filcon1=21
if n_elements(filcon2) eq 0 then filcon2=31
if n_elements(tstart) eq 0 then tstart = '27-jan-98'
if n_elements(tstop)  eq 0 then tstop  = !stime
tt_sfc  = tim2dset(rm_sfc0, tstart)
tt_sft  = tim2dset(rm_sft0, tstart)
tt_sfc1 = tim2dset(rm_sfc0, tstop)
tt_sft1 = tim2dset(rm_sft0, tstop)
rm_sfc = rm_sfc0(tt_sfc:tt_sfc1)
rm_sft = rm_sft0(tt_sft:tt_sft1)
n_sfc = n_elements(rm_sfc)
rd_sda,inf_sfc,tt_sfc+indgen(tt_sfc1-tt_sfc+1),ind_sfc,/nodata
xy = ind_sfc.his.sun_center
xy = xy(0:1,*)
;xy = sxt_cen(rm_sfc)
xy_sfc = xy
if n_elements(quiet) eq 0 then begin
  print,' '
  print,'Current SFC images with SXT_CEN values'
  print,' '
  for i = 0,n_sfc-1 do print,fmt_tim(rm_sfc(i)),' ',$
    gt_filta(rm_sfc(i),/str),' ',gt_filtb(rm_sfc(i),/str),$
    ' ',gt_filta(rm_sfc(i),/str),$
    xy(0,i), xy(1,i)
  print,' '
  print,"Time range of SFC's:"
  fmt_timer,rm_sfc
  print,' '
  dum = where(gt_filtb(rm_sfc) eq 2 and gt_filta(rm_sfc) eq 1, n21)
  dum = where(gt_filtb(rm_sfc) eq 3 and gt_filta(rm_sfc) eq 1, n31)
  dum = where(gt_filtb(rm_sfc) eq 4 and gt_filta(rm_sfc) eq 1, n41)
  dum = where(gt_filtb(rm_sfc) eq 5 and gt_filta(rm_sfc) eq 1, n51)
  dum = where(gt_filtb(rm_sfc) eq 6 and gt_filta(rm_sfc) eq 1, n61)
  dum = where(gt_filtb(rm_sfc) eq 2 and gt_filta(rm_sfc) eq 6, n26)
  dum = where(gt_filtb(rm_sfc) eq 3 and gt_filta(rm_sfc) eq 6, n36)
  dum = where(gt_filtb(rm_sfc) eq 4 and gt_filta(rm_sfc) eq 6, n46)
  dum = where(gt_filtb(rm_sfc) eq 5 and gt_filta(rm_sfc) eq 6, n56)
  dum = where(gt_filtb(rm_sfc) eq 6 and gt_filta(rm_sfc) eq 6, n66)
  bfil1=fix(filcon1/10)
  afil1=fix(filcon1-10*bfil1)
  bfil2=fix(filcon2/10)
  afil2=fix(filcon2-10*bfil2)
  dum_fc1=where(gt_filtb(rm_sfc) eq bfil1 and gt_filta(rm_sfc) eq afil1)
  dum_fc2=where(gt_filtb(rm_sfc) eq bfil2 and gt_filta(rm_sfc) eq afil2)
  print,'Filter summary:'
  print,'            Al.1        AlMg          Be        Al12          Mg'
  print,'Open', n21, n31, n41, n51, n61
  print,'ND  ', n26, n36, n46, n56, n66
  print,' '
  if !d.name ne 'TEK' then linecolors
  if keyword_set(wide) then begin
    if !d.name eq 'X' then wdef,0,800,800
    ss = where(gt_filtb(rm_sfc) eq bfil1 and gt_filta(rm_sfc) eq afil1, n_ss)
    !p.multi = [0,1,2]
    plot,xy(0,ss),xy(1,ss),psym=1,$
      tit = 'S/C W.........filcon1.........S/C E',yr=[500,650],xr=[300,800]
    oplot,[xy(0,ss(n_ss-1)),xy(0,ss(n_ss-1))],$
      [xy(1,ss(n_ss-1)),xy(1,ss(n_ss-1))], psym=4,symsiz=3,color=7
    oplot,[xy(0,ss(n_ss-2)),xy(0,ss(n_ss-2))],$
      [xy(1,ss(n_ss-2)),xy(1,ss(n_ss-2))], psym=4,symsiz=3,color=7
    ss = where(gt_filtb(rm_sfc) eq bfil2 and gt_filta(rm_sfc) eq afil2, n_ss)
    plot,xy(0,ss),xy(1,ss),psym=1,$
      tit = 'S/C W..........filcon2........S/C E',yr=[500,650],xr=[300,800]
    oplot,[xy(0,ss(n_ss-1)),xy(0,ss(n_ss-1))],$
      [xy(1,ss(n_ss-1)),xy(1,ss(n_ss-1))], psym=4,symsiz=3,color=7
    !p.multi = 0
  endif else begin
    if !d.name eq 'X' then wdef,0,800,400
    !p.multi = [0,2,1]
    ss = where(xy(0,*) gt 530 and xy(0,*) lt 545, n_ss)
    plot,xy(0,dum_fc2),xy(1,dum_fc2),psym=1,yr=[550,610],xr=[530,545],/nodata
    oplot,xy(0,dum_fc2),xy(1,dum_fc2),psym=1, color=9
    if n_ss ge 5 then begin
      for j = 0, 4 do begin
        oplot,[xy(0,ss(n_ss-5+j)),xy(0,ss(n_ss-5+j))],$
        [xy(1,ss(n_ss-5+j)),xy(1,ss(n_ss-5+j))], psym=4,symsiz=4
      endfor
    endif
    oplot,xy(0,dum_fc1),xy(1,dum_fc1), psym = 1,color=2
    utplot, rm_sfc, xy(1,*),psym=1,lines=1,xstyle=2, ystyle=2, yr=[550,610]
;   outplot,['12-dec-96','12-dec-96'],[0,700],lines=1
;   outplot,['17-apr-97','17-apr-97'],[0,700],lines=1
;   outplot,['14-may-97','14-may-97'],[0,700],lines=1
;   outplot,[' 4-jun-97',' 4-jun-97'],[0,700],lines=1
;   outplot,['18-jun-97','18-jun-97'],[0,700],lines=1
;   outplot,['16-aug-97','16-aug-97'],[0,700],lines=1
;   outplot,[' 3-sep-97',' 3-sep-97'],[0,700],lines=1
;   outplot,['21-oct-97','21-oct-97'],[0,700],lines=1
;   outplot,['22-dec-97','22-dec-97'],[0,700],lines=1
    outplot,[ '4-mar-98', '4-mar-98'],[0,700],lines=1
    outplot,[ '31-mar-98', '31-mar-98'],[0,700],lines=1
    outplot,[ '11-may-98', '11-may-98'],[0,700],lines=1
    outplot,[ '18-may-98', '18-may-98'],[0,700],lines=1
    if n_ss ge 5 then begin
      for j = 0, 4 do begin
        outplot, [rm_sfc(ss(n_ss-5+j)),rm_sfc(ss(n_ss-5+j))],$
          [xy(1,ss(n_ss-5+j)),xy(1,ss(n_ss-5+j))], psym=4,symsiz=4
      endfor
    endif
    !p.multi = 0
  endelse
endif
plottime	; Added 6-jan-99 by DMcK
out_img=tvrd()
write_gif,'$DIR_SITE_FTP/pub/sxt_co/quick/term_review1.gif',out_img
write_gif,'$DIR_SITE_FTP/pub/sxt_co/quick/term_review1_thumb.gif',$
  congrid(out_img,128,128)
print,"  The diamonds show the most recent SFC entries (all filters). "
print,"  If they are at one extreme limit of the range, consider re-pointing "
print,"  Yohkoh to keep up with the drift."
print," "
print,"  The left panel shows filters  ",strtrim(gt_filtb(bfil1,/str)),$
        "/",strtrim(gt_filta(afil1,/str))," (red) "
print,"  and filters  ",strtrim(gt_filtb(bfil2,/str)),"/",$
        strtrim(gt_filta(afil2,/str))," (blue). "  ;Made strings,08-feb-99(DMcK)
print," "
if keyword_set(compare) then begin
;  get_sfm_xy, '1-sep-96', !stime, xy_sfm
  if !d.name eq 'X' then wdef,1
;  plot,xy_sfm(0,*),xy_sfm(1,*),psym=4,symsi=2,xr=[525,550],yr=[570,610]
;  oplot,xy_sfc(0,*),xy_sfc(0,*),psym=2,symsi=2
  plot,xy_sfc(0,*),xy_sfc(1,*),psym=4,symsi=2,xr=[525,550],yr=[570,620]
  lastsfd,index,data,20,/notv
  xy_sfd = sxt_cen(index)
  oplot, xy_sfd(0,*), xy_sfd(1,*), psym = 2, symsi = 2,color=4 ;added color 08-feb-99(DMcK)
endif
if keyword_set(set) then begin
  i = 9
  lastsfd,index,data,20,/notv
  xy_sfd = sxt_cen(index)
  print,' '
  print,"Showing the last ThinAl SFC's (. and *) and the last 10 SFD's (+) for reference"
  print,' '
  while i lt 10 do begin
    i = i+1
    if !d.name eq 'X' then wdef,1
    thal = thinal_index(rm_sfc)
    plot,xy_sfc(0,thal),xy_sfc(1,thal),psym=3,xr=[530,545],yr=[540,620]
    oplot,xy_sfd(0,*),xy_sfd(1,*),psym=1
    nn = n_sfc-1
    oplot,[xy_sfc(0,nn),xy_sfc(0,nn)],[xy_sfc(1,nn),xy_sfc(1,nn)],$
      psym=2
    print,'Select best guess at current pointing'
    cursor,x1,y1,/data & print,x1,y1
    pause
    print,'Select target'
    cursor,x2,y2,/data & print,x2,y2
    pause
    pix = gt_pix_size()
    print,'Increment Euler angles (X, Y) by: '
    print,   (y2-y1)*pix,  (x2-x1)*pix, ' arc sec'
    arrow,x1,y1,x2,y2,/data
  endwhile
endif
plottime	; Added 6-jan-99 by DMcK
out_img = tvrd()
linecolors
tvlct,r,g,b,/get
write_gif,'$DIR_SITE_FTP/pub/sxt_co/quick/term_review2.gif',out_img
write_gif,'$DIR_SITE_FTP/pub/sxt_co/quick/term_review2_thumb.gif',$
  congrid(out_img,128,128),r,g,b
clearplot
clear_utplot
set_plot,'x'
if keyword_set(qstop) then stop
end
